Intel-XE Archive on lore.kernel.org
 help / color / mirror / Atom feed
From: "Thomas Hellström" <thomas.hellstrom@linux.intel.com>
To: intel-xe@lists.freedesktop.org
Cc: "Thomas Hellström" <thomas.hellstrom@linux.intel.com>
Subject: [PATCH 4/5] drm/xe: Rename EXEC_MODE_LR to EXEC_MODE_FAULT in hw engine group
Date: Fri, 22 May 2026 18:43:54 +0200	[thread overview]
Message-ID: <20260522164355.2773-5-thomas.hellstrom@linux.intel.com> (raw)
In-Reply-To: <20260522164355.2773-1-thomas.hellstrom@linux.intel.com>

The execution mode tracked by xe_hw_engine_group_execution_mode
describes whether the hw engine group is currently executing jobs
in fault mode (long-running, fault-capable) or in DMA fence mode.
The EXEC_MODE_LR label was misleading since not all LR queues use
fault mode; rename it to EXEC_MODE_FAULT for clarity.

No functional change.

Assisted-by: GitHub_Copilot:claude-sonnet-4.6
Signed-off-by: Thomas Hellström <thomas.hellstrom@linux.intel.com>
---
 drivers/gpu/drm/xe/xe_exec.c                  |  2 +-
 drivers/gpu/drm/xe/xe_hw_engine_group.c       | 10 +++++-----
 drivers/gpu/drm/xe/xe_hw_engine_group_types.h |  4 ++--
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/drivers/gpu/drm/xe/xe_exec.c b/drivers/gpu/drm/xe/xe_exec.c
index e05dabfcd43c..15ad0fee906c 100644
--- a/drivers/gpu/drm/xe/xe_exec.c
+++ b/drivers/gpu/drm/xe/xe_exec.c
@@ -342,7 +342,7 @@ int xe_exec_ioctl(struct drm_device *dev, void *data, struct drm_file *file)
 		spin_unlock(&xe->ttm.lru_lock);
 	}
 
-	if (mode == EXEC_MODE_LR)
+	if (mode == EXEC_MODE_FAULT)
 		xe_hw_engine_group_resume_faulting_lr_jobs(group);
 
 err_repin:
diff --git a/drivers/gpu/drm/xe/xe_hw_engine_group.c b/drivers/gpu/drm/xe/xe_hw_engine_group.c
index 791be6edd0a4..fba0ed039bad 100644
--- a/drivers/gpu/drm/xe/xe_hw_engine_group.c
+++ b/drivers/gpu/drm/xe/xe_hw_engine_group.c
@@ -22,12 +22,12 @@ hw_engine_group_resume_lr_jobs_func(struct work_struct *w)
 	int err;
 	enum xe_hw_engine_group_execution_mode previous_mode;
 
-	err = xe_hw_engine_group_get_mode(group, EXEC_MODE_LR, &previous_mode,
+	err = xe_hw_engine_group_get_mode(group, EXEC_MODE_FAULT, &previous_mode,
 					  NULL, 0);
 	if (err)
 		return;
 
-	if (previous_mode == EXEC_MODE_LR)
+	if (previous_mode == EXEC_MODE_FAULT)
 		goto put;
 
 	list_for_each_entry(q, &group->exec_queue_list, hw_engine_group_link) {
@@ -292,13 +292,13 @@ static int switch_mode(struct xe_hw_engine_group *group, bool has_deps)
 	lockdep_assert_held_write(&group->mode_sem);
 
 	switch (group->cur_mode) {
-	case EXEC_MODE_LR:
+	case EXEC_MODE_FAULT:
 		new_mode = EXEC_MODE_DMA_FENCE;
 		err = xe_hw_engine_group_suspend_faulting_lr_jobs(group,
 								  has_deps);
 		break;
 	case EXEC_MODE_DMA_FENCE:
-		new_mode = EXEC_MODE_LR;
+		new_mode = EXEC_MODE_FAULT;
 		err = xe_hw_engine_group_wait_for_dma_fence_jobs(group);
 		break;
 	}
@@ -395,7 +395,7 @@ enum xe_hw_engine_group_execution_mode
 xe_hw_engine_group_find_exec_mode(struct xe_exec_queue *q)
 {
 	if (xe_vm_in_fault_mode(q->vm))
-		return EXEC_MODE_LR;
+		return EXEC_MODE_FAULT;
 	else
 		return EXEC_MODE_DMA_FENCE;
 }
diff --git a/drivers/gpu/drm/xe/xe_hw_engine_group_types.h b/drivers/gpu/drm/xe/xe_hw_engine_group_types.h
index 92b6e0712c03..b4c41de6ba5f 100644
--- a/drivers/gpu/drm/xe/xe_hw_engine_group_types.h
+++ b/drivers/gpu/drm/xe/xe_hw_engine_group_types.h
@@ -14,11 +14,11 @@
  * enum xe_hw_engine_group_execution_mode - possible execution modes of a hw
  * engine group
  *
  * @EXEC_MODE_LR: execution in long-running mode
  * @EXEC_MODE_DMA_FENCE: execution in dma fence mode
  */
 enum xe_hw_engine_group_execution_mode {
-	EXEC_MODE_LR,
+	EXEC_MODE_FAULT,
 	EXEC_MODE_DMA_FENCE,
 };
 
@@ -14,11 +14,11 @@
  * engine group
  *
- * @EXEC_MODE_LR: execution in long-running mode
+ * @EXEC_MODE_FAULT: execution in fault mode (long-running, fault-capable)
  * @EXEC_MODE_DMA_FENCE: execution in dma fence mode
  */
-- 
2.54.0


  parent reply	other threads:[~2026-05-22 16:44 UTC|newest]

Thread overview: 9+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-05-22 16:43 [PATCH 0/5] drm/xe: Fix LR exec queue suspend/resume for S3/S4 Thomas Hellström
2026-05-22 16:43 ` [PATCH 1/5] drm/xe/guc: Defer user exec queue scheduler start until after page table restore Thomas Hellström
2026-05-22 16:43 ` [PATCH 2/5] drm/xe/guc: Don't ban LR VM exec queues on PM suspend Thomas Hellström
2026-05-22 16:43 ` [PATCH 3/5] drm/xe/guc: Add suspend refcount to exec queue ops Thomas Hellström
2026-05-22 16:43 ` Thomas Hellström [this message]
2026-05-22 16:43 ` [PATCH 5/5] drm/xe: Suspend fault-mode LR jobs before VRAM eviction on S3/S4 Thomas Hellström
2026-05-22 18:46 ` ✓ CI.KUnit: success for drm/xe: Fix LR exec queue suspend/resume for S3/S4 (rev2) Patchwork
2026-05-22 19:23 ` ✗ Xe.CI.BAT: failure " Patchwork
2026-05-23  3:23 ` ✗ Xe.CI.FULL: " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260522164355.2773-5-thomas.hellstrom@linux.intel.com \
    --to=thomas.hellstrom@linux.intel.com \
    --cc=intel-xe@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox